// $Id: ErrorCodes.h 1201 2021-08-13 20:15:05Z ge $
/// \file ErrorCodes.h
/// \brief contains predefined error codes
///
/// $Revision: 1201 $
/// \author Gerald Weber <gweberbh@gmail.com>
#ifndef ERRORCODES_H
#define ERRORCODES_H "$Id: ErrorCodes.h 1201 2021-08-13 20:15:05Z ge $"

#define CERR std::cerr 

#define CERR_ERROR(CODE) \
std::cerr << ":" << CODE << ":" << __FILE__ << "@" << __LINE__ << ": Error "

#define CERR_IERROR(CODE) \
std::cerr << ":" << CODE << ":" << __FILE__ << "@" << __LINE__ << ": Internal Error "

#define CERR_WARN(CODE) \
std::cerr << ":" << CODE << "@" << __LINE__ << ": Warning "

#define CERR_DEBUG(CODE) \
std::cerr << ":" << CODE << ":"

#define COUT_INFO(CODE) \
std::cout << ":" << CODE << ":"

#define CERR_TERM std::cerr << "Program terminating" << std::endl; exit(1);

//Problems with numerical routines start with 100
#define ERROR_REGRESSION   100 //(Debug)Linear GSL regression returned NaN values

//Problems with specific calculations start with 200
#define ERROR_MELTINGINDEX 200 //(removed)Melting index returned zero

//Problems with base pair or NN interpretation start with 300
#define ERROR_VOIDEXACTNEIGHBOURS 300 //Void pSI->Exact_neighbours

//Problems with options start with 400
#define ERROR_WRONG_PG_VALUE 400 //Unrecognized -pg value
#define ERROR_WRONG_PM_VALUE 401 //Unrecognized -pm value

//base/sequencestructure/SequenceDataset.h
#define ERRSCSDNE "ERRSCSDNE"   //Error: Salt correction scheme " << scheme << " does not exists
#define ERRESBER  "ERRESBER"   //Error: ExclusivePNeighbours_set.size()+NPNeighbours_set.size() should be equal to Reduced_neighbours_set.size()
#define ERRFXDNE "ERRFXDNE"    //"File " << xmlfile << " does not exist"
#define ERRFRDNE "ERRFRDNE"    //File " << rulefile << " does not exist
#define ERRCNRR  "ERRCNRR"     //Could not read " << rulefile
#define ERRCNIRL "ERRCNIRL"    //Could not interpret rule line [" << line << "] check for formatting mistakes
#define ERRPMT   "ERRPMT"      //Possibly malformed trimer
#define ERRUTPL  "ERRUTPL"     //Error unable to parse line
#define ERRFDFXNR "ERRFDFXNR"  //Format of data file " << xmlfile.c_str() << " not recognized
#define WSCIZ "WSCIZ"          //warning: species concentration is zero (Ct=0)
#define WDHMSC    "WDHMSC"     //dataset " << Dataset_filename << " has multiple salt concentrations
#define INFOSRSC  "INFOSRSC"   //Setting reference species concentration to
#define INFODHMSC "INFODHMSC"  //dataset " << Dataset_filename << " has multiple species concentrations
#define INFOSBSCT "INFOSBSCT"  //Setting base salt concentration to " <<  Salt_concentration << " from sequence
#define INFOTRRF  "INFOTRRF"   //trimer rules read from file
#define INFOTWMTL "INFOTWMTL"  //Trimer equivalence map too long, output suppressed

//base/parameters/ParameterMap.h
#define ERRNPF "ERRNPF"
#define TXTNPF "no specific or generic parameter found for "

//base/parameters/ParameterMap.h
#define ERRCHMP "ERRCHMP"
#define TXTCHMP "cannot handle multiple prefixes for "

//base/parameters/ParameterMap.h
#define ERRTJDPT "ERRTJDPT"

///home/ge/svn/bioinf/projects/base/sequencestructure/SequenceInfo.h
#define ERRSCNWC "ERRSCNWC" //salt correction nakano99 wrong concentrations
#define ERRTSCZ "ERRTSCZ" //target salt concentration is zero

//INN projects/thermodynamics/gibbs/IndividualNearestNeighbours.h
#define WINNSCIZ "WINNSCIZ" //species concentration is zero
#define WNSEEV "WNSEEV" //no specific Enthalpy or Entropy values, falling back to generic values
#define DINNHSG "DINNHSG" //dArU_dCrG DeltaH = -9.5 DeltaS = -26 DeltaG = -1.4361
#define DINNPTHSG "DINNPTHSG" //Partial total (before initiation) DeltaH = -160.7 DeltaS = -439.3 Delta G(37C) = -24.4511
#define DINNFPN "DINNFPN" //formatted_parameter_name
#define DINNSIED "DINNSIED" //sequence Sequence_info->Exact_duplex
#define DTMATENTH "DTMATENTH" //Terminal_AT_enthalpy
#define DTMATENTR "DTMATENTR" //Terminal_AT_entropy
#define DTMATDLTG "DTMATDLTG" //Terminal_AT_DeltaG
#define DTMCGENTH "DTMCGENTH" //Terminal_CG_enthalpy
#define DTMCGENTR "DTMCGENTR" //Terminal_CG_entropy
#define DTMCGDLTG "DTMCGDLTG" //Terminal_CG_DeltaG
#define DTDARUDTRAONLYENTH "DTDARUDTRAONLYENTH" //Terminal_dArU_dTrA_only_enthalpy
#define DTDARUDTRAONLYENTR "DTDARUDTRAONLYENTR" //Terminal_dArU_dTrA_only_entropy
#define DTDARUDTRAONLYDLTG "DTDARUDTRAONLYDLTG" //Terminal_dArU_dTrA_only_DeltaG
#define DTDCRGDGRCENTH "DTDCRGDGRCENTH" //Terminal_dCrG_dGrC_enthalpy
#define DTDCRGDGRCENTR "DTDCRGDGRCENTR" //Terminal_dCrG_dGrC_entropy
#define DTDCRGDGRCDLTG "DTDCRGDGRCDLTG" //Terminal_dCrG_dGrC_DeltaG
#define DINENTH "DINENTH" //Initiation_enthalpy
#define DINENTR "DINENTR" //Initiation_entropy
#define DINDLTG "DINDLTG" //Initiation_DeltaG
#define DSYCORRENTR "DSYCORRENTR" //Symmetry correction entropy
#define DSYCORRENTH "DSYCORRENTH" //Symmetry correction enthalpy
#define DTDHDSDG "DTDHDSDG" //Total DH = -149.7 Total DS = -413.8 Total DG = -21.3599

#endif
